@@ -4,7 +4,7 @@ import pyprotobuf.nodes as nodes
 from pyprotobuf.visitor import Visitor
 from pyprotobuf.outputbuffer import OutputBuffer
 
-logger = logging.getLogger("pyprotobuf.codegen")
+logger = logging.getLogger("pyprotobuf.Frame")
 
 
 class Frame(object):
@@ -39,19 +39,20 @@ class Frame(object):
         if not isinstance(node, (nodes.MessageNode, nodes.EnumNode)):
             return
         
-        logger.debug('Adding node %s', node.name)
+
         
         if self.id_scope[-1] == '':
             fullname = node.name
         else:
             fullname = '%s.%s' % (self.id_scope[-1], node.name)
-            
-        logger.debug('Adding fqn %s', fullname)
+
+        logger.debug('Add node: %s (%s)', fullname, node.__class__.__name__)
+
         
         self.global_scope[-1][fullname] = node
         self.local_scope[-1][node.name] = node
         
-        logger.debug('Current ids:%s ', self.global_scope[-1].keys())
+        #logger.debug('Current ids:%s ', self.global_scope[-1].keys())
         
     def push_local_scope(self):
         self.local_scope.append({})
