@@ -1,8 +1,8 @@
 from pyprotobuf.codegenerator import CodeGenerator
 
 class CommentResolver(CodeGenerator):
-    ''' associate comments with suceeding nodes 
-    '''
+    """ associate comments with suceeding nodes
+    """
     def __init__(self, frame=None):
         super(CommentResolver, self).__init__(frame)
         self.last_comment = None
@@ -19,7 +19,3 @@ class CommentResolver(CodeGenerator):
     
     def visit_CommentNode(self, child):
         self.last_comment = child
-        
-        
-    def visit_unknown(self, child):
-        print 'unknown', child
