@@ -4,11 +4,11 @@ from pyprotobuf.codegenerator import CodeGenerator
 
 
 class NameCollector(CodeGenerator):
-    ''' Collects global names into the Frame so the NameResolver doesnt depend on order.
-    '''
+    """ Collects global names into the Frame so the NameResolver doesnt depend on order.
+    """
 
     logger = logging.getLogger('pyprotobuf.NameCollector')
     
     def visit_MessageNode(self, node):
-        self.logger.debug('Adding message %s', node)
+        self.logger.debug('Adding message %s', node.get_full_name())
         self.frame.add_node(node)
\ No newline at end of file
