@@ -9,9 +9,18 @@ class ParseNode(object):
         self.type = None
         self.comment = None
 
+        # dependencies used for topological sorting
+        self.dependencies = set()
+
+    def get_file(self):
+        for parent in self.get_parents():
+            if isinstance(parent, FileNode):
+                return parent
+
     def add_child(self, c):
         assert isinstance(c, ParseNode), "Child must be a ParseNode. Got %s" % type(c)
         self.children.append(c)
+        c.parent = self
 
     def get_child(self, index):
         return self.children[index]
@@ -26,6 +35,20 @@ class ParseNode(object):
 
         return '.'.join(list(reversed(fqn)))
 
+    def add_dependency(self, dep):
+        self.dependencies.add(dep)
+        for parent in self.get_parents():
+            parent.add_dependency(dep)
+
+    def get_dependencies(self):
+        return self.dependencies
+
+    def get_parents(self):
+        parent = self.parent
+        while parent is not None:
+            yield parent
+            parent = parent.parent
+
     def get_full_name(self):
         fqn = [self.name]
         parent = self.parent
@@ -149,6 +172,13 @@ class FieldDescriptorNode(ParseNode):
 
 
 class EnumNode(ParseNode):
+    def get(self, key):
+        for c in self.children:
+            if c.name == key:
+                return c
+
+        return None
+
     def __str__(self):
         return 'enum %s { %s }' % (self.name, ' '.join(map(str, self.children)) )
 
