@@ -105,8 +105,8 @@ class ProtoParser(object):
         pass
 
     def parse_string(self, s):
-        ''' proto =( message | extend | enum | import | package | option | ';' ) ; 
-        '''
+        """ proto =( message | extend | enum | import | package | option | ';' ) ;
+        """
         tokenizer = Tokenizer(s)
 
         # the root is an anonymous package node
@@ -270,10 +270,10 @@ class ProtoParser(object):
 
 
     def parse_service_stmt(self, t):
-        '''
+        """
             service_defs = (option	 | method_def  | ';')+ ;
             service = 'service' ident '{' service_defs? '}' ;
-        '''
+        """
         node = ServiceNode()
         node.name = self.read_name(t)
 
@@ -290,16 +290,16 @@ class ProtoParser(object):
             elif self.check_single_line_comment(token):
                 node.add_child(self.read_single_line_comment(t))
             elif self.check_multiline_line_comment(t, token):
-                self.protonode.add_child(self.read_multi_line_comment(tokenizer))
+                self.protonode.add_child(self.read_multi_line_comment(t))
             elif token.type == TOKEN_OP and token.value == '}':
                 break
 
         return node
 
     def parse_method_def(self, t):
-        ''' method_options = '{' (option | ';')+ '}' ;
+        """ method_options = '{' (option | ';')+ '}' ;
             method_def = 'rpc' ident '(' qualified_name ')' 'returns' '(' qualified_name ')' (method_options | ';') ;
-        '''
+        """
         node = MethodNode()
         node.name = self.read_name(t)
         self.assert_read(t, TOKEN_OP, '(')
@@ -313,12 +313,12 @@ class ProtoParser(object):
 
 
     def parse_option_stmt(self, t):
-        '''
+        """
             option = 'option' optionBody ';';
             optionBody = ident ( '.' ident )* '=' constant;
-            
+
             # XXX: what are the parens for: "option (key) = value;" ?
-        '''
+        """
         node = OptionNode()
 
         token = t.readahead()
@@ -350,10 +350,10 @@ class ProtoParser(object):
         return node
 
     def parse_message_stmt(self, t):
-        '''
+        """
             message ='message' ident messageBody;
             messageBody ='{' ( field | enum | message | extend | extensions | group | option | ':' )* '}';
-        '''
+        """
         message_name = self.read_name(t)
 
         self.assert_read(t, TOKEN_OP, '{')
@@ -375,7 +375,7 @@ class ProtoParser(object):
                 node = self.read_single_line_comment(t)
                 mnode.add_child(node)
             elif self.check_multiline_line_comment(t, token):
-                self.protonode.add_child(self.read_multi_line_comment(tokenizer))
+                self.protonode.add_child(self.read_multi_line_comment(t))
             elif self.check_names(token, ['extensions']):
                 node = self.parse_extensions_stmt(t)
                 mnode.add_child(node)
@@ -397,12 +397,12 @@ class ProtoParser(object):
         return mnode
 
     def parse_extensions_stmt(self, t):
-        ''' 
+        """
             # extension numbers must not overlap with field or other extension numbers;
             extensions = 'extensions' extension ( ',' extension )* ';';
 
             extension = intLit ( 'to' ( intLit | 'max' ) )?;
-        '''
+        """
         ext = ExtensionsNode()
         ext.start = t.next_token().value
         totoken = t.next_token()
@@ -419,11 +419,11 @@ class ProtoParser(object):
         return node
 
     def parse_enum_stmt(self, t):
-        '''
+        """
             enum ='enum' ident '{' ( option | enumField | ';' )* '}';
 
             enumField =ident '=' intLit ';';
-        '''
+        """
         enum = EnumNode()
         enum.name = t.next_token().value
         self.assert_read(t, TOKEN_OP, '{')
@@ -440,7 +440,7 @@ class ProtoParser(object):
                 node = self.read_single_line_comment(t)
                 enum.add_child(node)
             elif self.check_multiline_line_comment(t, token):
-                self.protonode.add_child(self.read_multi_line_comment(tokenizer))
+                self.protonode.add_child(self.read_multi_line_comment(t))
             elif token.type == TOKEN_NAME:
                 enum.add_child(self.parse_enumassignment_stmt(t))
             else:
@@ -457,9 +457,9 @@ class ProtoParser(object):
         return enumassign
 
     def parse_extend_stmt(self, t):
-        ''' 
+        """
             extend ='extend' userType '{' ( field | group | ';' )* '}';
-        '''
+        """
         extend = ExtendNode()
         extend.name = t.next_token().value
         token = t.next_token()
@@ -471,7 +471,7 @@ class ProtoParser(object):
                 node = self.read_single_line_comment(t)
                 extend.add_child(node)
             elif self.check_multiline_line_comment(t, token):
-                self.protonode.add_child(self.read_multi_line_comment(tokenizer))
+                self.protonode.add_child(self.read_multi_line_comment(t))
             elif token.value == 'optional':
                 extend.add_child(self.parse_optional_stmt(t))
             else:
@@ -479,8 +479,8 @@ class ProtoParser(object):
         return extend
 
     def parse_import_stmt(self, t):
-        ''' import ='import' strLit ';';
-        '''
+        """ import ='import' strLit ';';
+        """
         # TODO: handle import public strLit;
         
         import_path = self.read_string_or_id(t)
@@ -492,8 +492,8 @@ class ProtoParser(object):
         return node
 
     def parse_package_stmt(self, t):
-        ''' package ='package' ident ( '.' ident )* ';';
-        '''
+        """ package ='package' ident ( '.' ident )* ';';
+        """
         package_name = t.read_id()
         semi = self.read_semi(t)
         package = PackageDefinition()
@@ -507,12 +507,12 @@ class ProtoParser(object):
         return package
 
     def parse_field_desc(self, t):
-        '''
+        """
             field =label type ident '=' intLit ( '[' fieldOption ( ',' fieldOption )* ']' )? ';';
             # tag number must be 2^29-1 or lower, not 0, and not 19000-19999 (reserved);
-            
+
             fieldOption =optionBody | 'default' '=' constant;
-        '''
+        """
         fdn = FieldDescriptorNode()
         fdn.label = t.next_token().value
         fdn.type = t.read_id()
