@@ -1,7 +1,5 @@
 import unittest
-import logging
 from pyprotobuf.parser import ProtoParser
-import pyprotobuf.parser
 import pyprotobuf.nodes as nodes
 
 TOPLEVEL_TEST = '''
@@ -49,7 +47,7 @@ service SearchService {
 
 class TestParser(unittest.TestCase):
     def test_toplevel(self):
-        ''' Basic top level statements '''
+        """ Basic top level statements """
         # test toplevel statements
         pp = ProtoParser()
         protonode = pp.parse_string(TOPLEVEL_TEST).get_child(0)
@@ -59,7 +57,7 @@ class TestParser(unittest.TestCase):
         self.assertIsInstance(protonode.get_child(3), nodes.OptionNode)
 
     def test_message_decl(self):
-        ''' Empty message decl. '''
+        """ Empty message decl. """
         pp = ProtoParser()
         protonode = pp.parse_string(MESSAGE_TEST).get_child(0)
         self.assertIsInstance(protonode.get_child(1), nodes.MessageNode)
